==> libbpp-seq_2.0.2.orig.tar.gz: bpp-seq-2.0.2/src/Bpp/Seq/Alphabet/DefaultAlphabet.cpp <==
//
// File: DefaultAlphabet.cpp
// Authors: Julien Dutheil
//          Sylvain Gaillard
// Created on: 2005
//

/*
Copyright or © or Copr. CNRS, (November 17, 2004)

This software is a computer program whose purpose is to provide classes
for sequences analysis.

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.
*/


#include "DefaultAlphabet.h"
#include "AlphabetState.h"
#include <Bpp/Text/TextTools.h>

using namespace bpp;

DefaultAlphabet::DefaultAlphabet():
  chars_("ABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890.?")
{
	// Alphabet size definition
	resize(chars_.size() + 1);

	// Alphabet content definition
  setState(0, AlphabetState(-1, "-", "Gap"));

	for(unsigned int i = 0; i < chars_.size(); i++)
  {
    setState(i+1, AlphabetState(i, TextTools::toString(chars_[i]), ""));
	}
}

==> libbpp-seq_2.1.0.orig.tar.gz: bpp-seq-2.1.0/src/Bpp/Seq/Alphabet/DefaultAlphabet.cpp <==
//
// File: DefaultAlphabet.cpp
// Authors: Julien Dutheil
//          Sylvain Gaillard
// Created on: 2005
//

/*
Copyright or © or Copr. CNRS, (November 17, 2004)

This software is a computer program whose purpose is to provide classes
for sequences analysis.

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.
*/


#include "DefaultAlphabet.h"
#include "AlphabetState.h"
#include <Bpp/Text/TextTools.h>

using namespace bpp;

DefaultAlphabet::DefaultAlphabet():
  chars_("ABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890.?")
{
	// Alphabet size definition
	resize(static_cast<unsigned int>(chars_.size()) + 1);

	// Alphabet content definition
  setState(0, AlphabetState(-1, "-", "Gap"));

	for (size_t i = 0; i < chars_.size(); i++)
  {
    setState(i + 1, AlphabetState(static_cast<int>(i), TextTools::toString(chars_[i]), ""));
	}
}
